@@ -1,18 +1,29 @@
 package Import::Base;
 # ABSTRACT: Import a set of modules into the calling module
-$Import::Base::VERSION = '0.005';
+$Import::Base::VERSION = '0.006';
 use strict;
 use warnings;
+use mro ();
 use Import::Into;
 use Module::Runtime qw( use_module );
 
 sub modules {
     my ( $class, $bundles, $args ) = @_;
     my @modules = ();
-    my %bundles = ();
-    return
-        @modules,
-        map { @{ $bundles{ $_ } } } grep { exists $bundles{ $_ } } @$bundles;
+
+    # Find all the modules from the static API
+    # Reverse the array to allow more-specific classes to override
+    # less-specific ones
+    for my $pkg ( reverse @{ mro::get_linear_isa( $class ) } ) {
+        no strict 'refs';
+        push @modules, @{ $pkg . "::IMPORT_MODULES" };
+        my %bundles = %{ $pkg . "::IMPORT_BUNDLES" };
+        push @modules, map { @{ $bundles{ $_ } } }
+            grep { exists $bundles{ $_ } }
+            @$bundles;
+    }
+
+    return @modules;
 }
 
 sub import {
@@ -76,38 +87,32 @@ Import::Base - Import a set of modules into the calling module
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
+    ### Static API
     package My::Base;
     use base 'Import::Base';
-    sub modules {
-        my ( $class, $bundles, $args ) = @_;
 
-        # Modules that are always imported
-        my @modules = (
-            'strict',
-            'warnings',
-            'My::Exporter' => [ 'foo', 'bar', 'baz' ],
-            '-warnings' => [qw( uninitialized )],
-        );
+    # Modules that are always imported
+    our @IMPORT_MODULES = (
+        'strict',
+        'warnings',
+        'My::Exporter' => [ 'foo', 'bar', 'baz' ],
+        '-warnings' => [qw( uninitialized )],
+    );
 
-        # Optional bundles
-        my %bundles = (
-            with_signatures => [
-                'feature' => [qw( signatures )],
-                '-warnings' => [qw( experimental::signatures )]
-            ],
-            Test => [qw( Test::More Test::Deep )],
-        );
-
-        # Return an array of imports/unimports
-        return $class->SUPER::modules( $bundles, $args ),
-            @modules,
-            map { @{ $bundles{ $_ } } } grep { exists $bundles{ $_ } } @$bundles;
-    }
+    # Optional bundles
+    our %IMPORT_BUNDLES = (
+        with_signatures => [
+            'feature' => [qw( signatures )],
+            '-warnings' => [qw( experimental::signatures )]
+        ],
+        Test => [qw( Test::More Test::Deep )],
+    );
 
+    ### Consumer classes
     # Use only the default set of modules
     use My::Base;
 
@@ -129,9 +134,10 @@ module boilerplate from 12 lines to 1.
 
 =head2 Base Module
 
-Creating a base module means extending Import::Base and overriding sub modules().
-modules() returns a list of modules to import, optionally with a arrayref of arguments
-to be passed to the module's import() method.
+Creating a base module means extending Import::Base and creating an
+C<@IMPORT_MODULES> package variable with a list of modules to import,
+optionally with a arrayref of arguments to be passed to the module's import()
+method.
 
 A common base module should probably include L<strict|strict>,
 L<warnings|warnings>, and a L<feature|feature> set.
@@ -139,14 +145,11 @@ L<warnings|warnings>, and a L<feature|feature> set.
     package My::Base;
     use base 'Import::Base';
 
-    sub modules {
-        my ( $class, $bundles, $args ) = @_;
-        return (
-            'strict',
-            'warnings',
-            feature => [qw( :5.14 )],
-        );
-    }
+    our @IMPORT_MODULES = (
+        'strict',
+        'warnings',
+        feature => [qw( :5.14 )],
+    );
 
 Now we can consume our base module by doing:
 
@@ -164,7 +167,104 @@ Now when we want to change our feature set, we only need to edit one file!
 
 =head2 Import Bundles
 
-In addition to a set of modules, we can also create optional bundles.
+In addition to a set of modules, we can also create optional bundles with the
+C<%IMPORT_BUNDLES> package variable.
+
+    package My::Bundles;
+    use base 'My::Base';
+
+    # Modules that will always be included
+    our @IMPORT_MODULES
+        experimental => [qw( signatures )],
+    );
+
+    # Named bundles to include
+    our %IMPORT_BUNDLES = (
+        Class => [qw( Moose MooseX::Types )],
+        Role => [qw( Moose::Role MooseX::Types )],
+        Test => [qw( Test::More Test::Deep )],
+    );
+
+Now we can choose one or more bundles to include:
+
+    # lib/MyClass.pm
+    use My::Base 'Class';
+
+    # t/mytest.t
+    use My::Base 'Test';
+
+    # t/lib/MyTest.pm
+    use My::Base 'Test', 'Class';
+
+Bundles must always come before options. Bundle names cannot start with "-".
+
+=head2 Extended Base Module
+
+We can further extend our base module to create more specialized modules for
+classes and testing.
+
+    package My::Class;
+    use base 'My::Base';
+    our @IMPORT_MODULES = (
+        'Moo::Lax',
+        'Types::Standard' => [qw( :all )],
+    );
+
+    package My::Test;
+    use base 'My::Base';
+    our @IMPORT_MODULES = (
+        'Test::More',
+        'Test::Deep',
+        'Test::Exception',
+        'Test::Differences',
+    );
+
+Now all our classes just need to C<use My::Class> and all our test scripts just
+need to C<use My::Test>.
+
+=head2 Unimporting
+
+Sometimes instead of C<use Module> we need to do C<no Module>, to turn off
+C<strict> or C<warnings> categories for example.
+
+By prefixing the module name with a C<->, Import::Base will act like C<no>
+instead of C<use>.
+
+    package My::Base;
+    use base 'Import::Base';
+    our @IMPORT_MODULES = (
+        'strict',
+        'warnings',
+        feature => [qw( :5.20 )],
+        '-warnings' => [qw( experimental::signatures )],
+    );
+
+Now the warnings for using the 5.20 subroutine signatures feature will be
+disabled.
+
+=head2 -exclude
+
+When importing a base module, you can use C<-exclude> to prevent certain things
+from being imported (if, for example, they would conflict with existing
+things).
+
+    # Prevent the "warnings" module from being imported
+    use My::Base -exclude => [ 'warnings' ];
+
+    # Prevent the "bar" sub from My::Exporter from being imported
+    use My::Base -exclude => [ 'My::Exporter' => [ 'bar' ] ];
+
+NOTE: If you find yourself using C<-exclude> often, you would be better off
+removing the module or sub and creating a bundle, or only including it in those
+modules that need it.
+
+=head2 Dynamic API
+
+Instead of providing C<@IMPORT_MODULES> and C<%IMPORT_BUNDLES>, you can override the
+C<modules()> method to do anything you want.
+
+One advantage the dynamic API has is the ability to remove modules from superclasses, or
+to have custom arguments (below).
 
     package My::Bundles;
     use base 'My::Base';
@@ -192,98 +292,14 @@ In addition to a set of modules, we can also create optional bundles.
             map { @{ $bundles{ $_ } } } grep { exists $bundles{ $_ } } @$bundles;
     }
 
-Now we can choose one or more bundles to include:
-
-    # lib/MyClass.pm
-    use My::Base 'Class';
-
-    # t/mytest.t
-    use My::Base 'Test';
-
-    # t/lib/MyTest.pm
-    use My::Base 'Test', 'Class';
-
-Bundles must always come before options. Bundle names cannot start with "-".
-
-=head2 Extended Base Module
-
-We can further extend our base module to create more specialized modules for
-classes and testing.
-
-    package My::Class;
-    use base 'My::Base';
-
-    sub modules {
-        my ( $class, $bundles, $args ) = @_;
-        return (
-            $class->SUPER::modules( $bundles, $args ),
-            'Moo::Lax',
-            'Types::Standard' => [qw( :all )],
-        );
-    }
-
-    package My::Test;
-    use base 'My::Base';
-
-    sub modules {
-        my ( $class, $bundles, $args ) = @_;
-        return (
-            $class->SUPER::modules( $bundles, $args ),
-            'Test::More',
-            'Test::Deep',
-            'Test::Exception',
-            'Test::Differences',
-        );
-    }
-
-Now all our classes just need to C<use My::Class> and all our test scripts just
-need to C<use My::Test>.
-
-=head2 Unimporting
-
-Sometimes instead of C<use Module> we need to do C<no Module>, to turn off
-C<strict> or C<warnings> categories for example.
-
-By prefixing the module name with a C<->, Import::Base will act like C<no>
-instead of C<use>.
-
-    package My::Base;
-    use base 'Import::Base';
-
-    sub modules {
-        my ( $class, $bundles, $args ) = @_;
-        return (
-            'strict',
-            'warnings',
-            feature => [qw( :5.20 )],
-            '-warnings' => [qw( experimental::signatures )],
-        );
-    }
-
-Now the warnings for using the 5.20 subroutine signatures feature will be
-disabled.
-
-=head2 -exclude
-
-When importing a base module, you can use C<-exclude> to prevent certain things
-from being imported (if, for example, they would conflict with existing
-things).
-
-    # Prevent the "warnings" module from being imported
-    use My::Base -exclude => [ 'warnings' ];
-
-    # Prevent the "bar" sub from My::Exporter from being imported
-    use My::Base -exclude => [ 'My::Exporter' => [ 'bar' ] ];
-
-NOTE: If you find yourself using C<-exclude> often, you would be better off
-removing the module or sub and creating a bundle, or only including it in those
-modules that need it.
+Using the above boilerplate will ensure that you start with all the basic functionality.
 
 =head2 Custom Arguments
 
-You can add any additional arguments to the C<use> line. The arguments list
-starts after the first key that starts with a '-'. To avoid conflicting with
-any future Import::Base feature, prefix all your custom arguments with '--'.
+If you are using the L</Dynamic API>, you can add any additional arguments to
+the C<use> line. The arguments list starts after the first key that starts with
+a '-'. To avoid conflicting with any future Import::Base feature, prefix all
+your custom arguments with '--'.
 
 =head1 METHODS
 
@@ -294,6 +310,93 @@ $args is a hash ref of generic arguments, if any.
 
 Returns a list of MODULE => [ import() args ]. MODULE may appear multiple times.
 
+=head1 DOCUMENTATION BOILERPLATE
+
+Here is an example for documenting your own base modules
+
+    =head1 SYNOPSIS
+
+        package MyModule;
+        use My::Base;
+
+        use My::Base 'Class';
+        use My::Base 'Role';
+        use My::Base 'Test';
+
+    =head1 DESCRIPTION
+
+    This is the base module that all {{PROJECT}} files should use.
+
+    This module always imports the following into your namespace:
+
+    =over
+
+    =item L<strict>
+
+    =item L<warnings>
+
+    =item L<feature>
+
+    Currently the 5.20 feature bundle
+
+    =item L<experimental> 'signatures' 'postderef'
+
+    We are using the 5.20 experimental signatures and postfix deref syntax.
+
+    =back
+
+    =head1 BUNDLES
+
+    The following bundles are available. You may import one or more of these by name.
+
+    =head2 Class
+
+    The class bundle makes your package into a class and includes:
+
+    =over 4
+
+    =item L<Moo::Lax>
+
+    =item L<Types::Standard> ':all'
+
+    =back
+
+    =head2 Role
+
+    The role bundle makes your package into a role and includes:
+
+    =over 4
+
+    =item L<Moo::Role::Lax>
+
+    =item L<Types::Standard> ':all'
+
+    =back
+
+    =head2 Test
+
+    The test bundle includes:
+
+    =over 4
+
+    =item L<Test::More>
+
+    =item L<Test::Deep>
+
+    =item L<Test::Differences>
+
+    =item L<Test::Exception>
+
+    =back
+
+    =head1 SEE ALSO
+
+    =over
+
+    =item L<Import::Base>
+
+    =back
+
 =head1 SEE ALSO
 
 =over
@@ -303,6 +406,11 @@ Returns a list of MODULE => [ import() args ]. MODULE may appear multiple times.
 The module that provides the functionality to create this module. If Import::Base
 doesn't do what you want, look at Import::Into to build your own.
 
+=item L<perl5|perl5>
+
+This module is very similar, and has a bunch of built-in bundles and features for
+quickly importing Perl feature sets.
+
 =item L<ToolSet|ToolSet>
 
 This is very similar, but does not appear to allow subclasses to remove imports from
